package de.intevation.flys.utils;

import java.awt.Color;

import org.w3c.dom.Document;

import de.intevation.artifacts.common.utils.XMLUtils;


/**
 * Utility to deal with themes and their representations.
 */
public class ThemeUtil {
    public final static String XPATH_LINE_COLOR = "/theme/field[@name='linecolor']/@default";

    /**
     * Parse a string like "103, 100, 0" and return a corresping color.
     * @param rgbtext Color as string representation, e.g. "255,0,20".
     * @return Color, null in case of issues.
     */
    public static Color parseRGB(String rgbtext) {
        if (rgbtext == null) {
            return null;
        }
        String rgb[] = rgbtext.split(",");
        Color c = null;
        try {
            c = new Color(
                    Integer.valueOf(rgb[0].trim()),
                    Integer.valueOf(rgb[1].trim()),
                    Integer.valueOf(rgb[2].trim()));
        }
        catch (NumberFormatException nfe) {
            c = null;
        }
        return c;
    }

    /**
     * Gets color from color field.
     * @param theme    the theme document.
     * @return color.
     */
    public static Color parseLineColorField(Document theme) {
        String color = XMLUtils.xpathString(theme, XPATH_LINE_COLOR, null);
        return parseRGB(color);
    }
}
